
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Alders
Alders'
Eilam
Eilam's
MaxMind
MaxMind's
Oschwald
Oschwald's
Rolsky
Rolsky's
API
APIs
AdWords
CN
GEONAMES
GeoIP
GeoLite
GeoNames
GitHub
IANA
IP
IP's
IPv
ISP
Knop
OC
Omni
Oxfordshire
SSL
URI
VERSIONING
VPN
YYY
YYYZZZ
contentDeliveryNetwork
de
dialup
downloadable
ergument
geoname_id
hostname
ip
ja
libmaxminddb
lookup
maxmind
omni
params
routable
ru
searchEngineSpider
ua
unpopulated
versioning
zh
Dave
drolsky
Greg
goschwald
Olaf
oalders
Inc
Graham
haarg
lib
GeoIP2
Role
Model
HasSubdivisions
Record
Postal
Country
Location
Error
HTTP
Insights
AnonymousIP
Generic
Types
Flat
Subdivision
Traits
RepresentedCountry
WebService
Client
HasNames
ConnectionType
HasLocales
Database
Reader
City
Continent
Domain
IPAddressNotFound
Type
HasIPAddress
